@@ -11,7 +11,7 @@ from reversebox.image.decoders.bumpmap_decoder import BumpmapDecoder
 from reversebox.image.decoders.compressed_decoder_encoder import (
     CompressedImageDecoderEncoder,
 )
-from reversebox.image.decoders.gst_decoder import GSTImageDecoder
+from reversebox.image.decoders.gst_decoder_encoder import GSTImageDecoderEncoder
 from reversebox.image.decoders.n64_decoder import N64Decoder
 from reversebox.image.decoders.pvrtexlib_decoder_encoder import (
     PvrTexlibImageDecoderEncoder,
@@ -74,8 +74,15 @@ class ImageDecoder:
         p[3] = 0xFF
         return p
 
-    # A8 (Alpha 8-bit)
-    def _decode_alpha8_pixel(self, pixel_int: int) -> bytes:
+    def _decode_alpha_16x_pixel(self, pixel_int: int) -> bytes:
+        p = bytearray(4)
+        p[0] = 0xFF
+        p[1] = 0xFF
+        p[2] = 0xFF
+        p[3] = (16 * pixel_int) & 0xFF
+        return p
+
+    def _decode_alpha_only_pixel(self, pixel_int: int) -> bytes:
         p = bytearray(4)
         p[0] = 0xFF
         p[1] = 0xFF
@@ -566,10 +573,13 @@ class ImageDecoder:
         # image_format: (decode_function, bits_per_pixel, image_entry_read_function)
         ImageFormats.RGB121: (_decode_rgb121_byte_pixel, 4, get_uint8),
         ImageFormats.N64_I4: (_decode_i4_pixel, 4, get_uint8),  # GRAY, 4bpp
+        ImageFormats.ALPHA4: (_decode_alpha_only_pixel, 4, get_uint8),
+        ImageFormats.ALPHA4_16X: (_decode_alpha_16x_pixel, 4, get_uint8),
 
         ImageFormats.RGB121_BYTE: (_decode_rgb121_byte_pixel, 8, get_uint8),
         ImageFormats.GRAY8: (_decode_gray8_pixel, 8, get_uint8),
-        ImageFormats.ALPHA8: (_decode_alpha8_pixel, 8, get_uint8),
+        ImageFormats.ALPHA8: (_decode_alpha_only_pixel, 8, get_uint8),
+        ImageFormats.ALPHA8_16X: (_decode_alpha_16x_pixel, 8, get_uint8),
         ImageFormats.LA44: (_decode_la44_pixel, 8, get_uint8),
         ImageFormats.RGBX2222: (_decode_rgbx2222_pixel, 8, get_uint8),
         ImageFormats.RGBA2222: (_decode_rgba2222_pixel, 8, get_uint8),
@@ -709,7 +719,7 @@ class ImageDecoder:
         return texture_data
 
     def _decode_indexed(self, image_data: bytes, palette_data: bytes, img_width: int,
-                        img_height: int, image_format: ImageFormats, palette_format: ImageFormats, image_endianess: str, palette_endianess: str) -> bytes:
+                        img_height: int, image_format: ImageFormats, palette_format: ImageFormats, image_endianess: str, palette_endianess: str, scale_value: int) -> bytes:
         img_bits_per_pixel = self.indexed_data_formats[image_format]
         decode_function, pal_bits_per_pixel, palette_entry_read_function = self.generic_data_formats[palette_format]
         palette_entry_size: int = convert_bpp_to_bytes_per_pixel(pal_bits_per_pixel)
@@ -724,7 +734,7 @@ class ImageDecoder:
         palette_data_ints: list = []
         for i in range(len(palette_data) // palette_entry_size):
             palette_entry = palette_handler.get_bytes(palette_offset, palette_entry_size)
-            palette_entry_int = palette_entry_read_function(palette_entry, palette_endianess_format)
+            palette_entry_int = palette_entry_read_function(palette_entry, palette_endianess_format) * scale_value
             palette_offset += palette_entry_size
             palette_data_ints.append(palette_entry_int)
 
@@ -804,8 +814,8 @@ class ImageDecoder:
     def decode_image(self, image_data: bytes, img_width: int, img_height: int, image_format: ImageFormats, image_endianess: str = "little") -> bytes:
         return self._decode_generic(image_data, img_width, img_height, self.generic_data_formats[image_format], image_endianess)
 
-    def decode_indexed_image(self, image_data: bytes, palette_data: bytes, img_width: int, img_height: int, image_format: ImageFormats, palette_format: ImageFormats, image_endianess: str = "little", palette_endianess: str = "little") -> bytes:
-        return self._decode_indexed(image_data, palette_data, img_width, img_height, image_format, palette_format, image_endianess, palette_endianess)
+    def decode_indexed_image(self, image_data: bytes, palette_data: bytes, img_width: int, img_height: int, image_format: ImageFormats, palette_format: ImageFormats, image_endianess: str = "little", palette_endianess: str = "little", scale_value: int = 1) -> bytes:
+        return self._decode_indexed(image_data, palette_data, img_width, img_height, image_format, palette_format, image_endianess, palette_endianess, scale_value)
 
     def decode_compressed_image(self, image_data: bytes, img_width: int, img_height: int, image_format: ImageFormats) -> bytes:
         return CompressedImageDecoderEncoder().decode_compressed_image_main(image_data, img_width, img_height, image_format)
@@ -814,7 +824,7 @@ class ImageDecoder:
         return PvrTexlibImageDecoderEncoder().decode_compressed_image_main(image_data, img_width, img_height, image_format)
 
     def decode_gst_image(self, image_data: bytes, palette_data: bytes, img_width: int, img_height: int, image_format: ImageFormats, convert_format: ImageFormats, convert_pal_format: ImageFormats, is_swizzled: bool = True) -> bytes:
-        gst_decoder = GSTImageDecoder()
+        gst_decoder = GSTImageDecoderEncoder()
         decoded_gst_data: bytes = gst_decoder.decode_gst_image_main(image_data, img_width, img_height, image_format, is_swizzled)
         return self.decode_indexed_image(decoded_gst_data, palette_data, img_width, img_height, convert_format, convert_pal_format)
 
